@@ -44,6 +44,7 @@ from .grpc import (
     device_helpers
 )
 from . import device_register, modulator
+from . import sources
 import json
 from rs4.attrdict import AttrDict
 
@@ -315,6 +316,21 @@ def use_device (device, lang = 'ko-KR', output_audio_file = None, once = True, d
     audio_source.close ()
     return resp
 
+def use_device_sd (device, lang = 'ko-KR', output_audio_file = None, once = True, display = True, verbose = False, *args, **kwargs):
+    if isinstance (device, (int, str)):
+        audio_source = sources.SoundDeviceStream(
+            sample_rate=16000,
+            sample_width=2,
+            block_size=6400,
+            flush_size=25600,
+            device = device
+        )
+    else:
+        audio_source = device # virtusl device
+    resp = assistant.send (audio_source, lang, output_audio_file, once, display, verbose, *args, **kwargs)
+    audio_source.close ()
+    return resp
+
 def transport (resp, output_path = '', lang = None):
     dialog = AttrDict ()
     dialog ['question'] = resp.question
